# -*- perl -*-
#
# This module was autogenerated by Module::TestConfig

package MyConfig;

use strict;
use Carp;
use vars '$AUTOLOAD';

sub new {
    my $proto = shift;
    my $class = ref $proto || $proto;
    my $self = {
          'to' => 'spam@mydomain.fr',
          'smtp' => 'mail.mydomain.fr',
          'from' => 'firstname.lastname@mydomain.fr',
          'hello' => 'mydomain.fr',
          'user' => 'mylogin',
          'port' => '25'
        }
;
    return bless $self, $class;
}

sub AUTOLOAD {
    my $self = shift;

    ($AUTOLOAD) = $AUTOLOAD =~ /(\w+)$/;

    croak "No such method: $AUTOLOAD"
        unless defined $self->{$AUTOLOAD}
            || $AUTOLOAD eq "DESTROY";

    return $self->{$AUTOLOAD};
}

1;

